A terminal tool, help you use git more simple.

Just support Linux, MacOs or other UNIX-like.

You can use Pipy install it.

```shell
pip3 install fungit --user
```

Then you can use it with `g` , like this:

```shell
[fungit]

A terminal tool, help you use git more simple. Support Linux and MacOS.

Usage: g <option> [<args>]
You can use -h and --help to get how to use fungit.

```
